#ifndef NT2_INCLUDE_CONSTANTS_SPLITFACTOR_HPP_INCLUDED
#define NT2_INCLUDE_CONSTANTS_SPLITFACTOR_HPP_INCLUDED

#include <nt2/constant/include/constants/splitfactor.hpp>

#endif
